@@ -139,8 +139,8 @@ _ggit_diff_wrap (git_diff_list *diff,
 /**
  * ggit_diff_new_tree_to_tree:
  * @repository: a #GgitRepository.
- * @old_tree: a #GgitTree to diff from.
- * @new_tree: a #GgitTree to diff to.
+ * @old_tree: (allow-none): a #GgitTree to diff from.
+ * @new_tree: (allow-none): a #GgitTree to diff to.
  * @diff_options: (allow-none): a #GgitDiffOptions, or %NULL.
  * @error: a #GError for error reporting, or %NULL.
  *
@@ -162,14 +162,15 @@ ggit_diff_new_tree_to_tree (GgitRepository   *repository,
 	gint ret;
 
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
-	g_return_val_if_fail (GGIT_IS_TREE (old_tree), NULL);
-	g_return_val_if_fail (GGIT_IS_TREE (new_tree), NULL);
+	g_return_val_if_fail (old_tree == NULL || GGIT_IS_TREE (old_tree), NULL);
+	g_return_val_if_fail (new_tree == NULL || GGIT_IS_TREE (new_tree), NULL);
+	g_return_val_if_fail (old_tree != NULL || new_tree != NULL, NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	ret = git_diff_tree_to_tree (&diff,
 	                             _ggit_native_get (repository),
-	                             _ggit_native_get (old_tree),
-	                             _ggit_native_get (new_tree),
+	                             old_tree ? _ggit_native_get (old_tree) : NULL,
+	                             new_tree ? _ggit_native_get (new_tree) : NULL,
 	                             _ggit_diff_options_get_diff_options (diff_options));
 
 	if (ret != GIT_OK)
@@ -184,7 +185,7 @@ ggit_diff_new_tree_to_tree (GgitRepository   *repository,
 /**
  * ggit_diff_new_tree_to_index:
  * @repository: a #GgitRepository.
- * @old_tree: a #GgitTree to diff from.
+ * @old_tree: (allow-none): a #GgitTree to diff from.
  * @index: (allow-none): a #GgitIndex, or %NULL.
  * @diff_options: (allow-none): a #GgitDiffOptions, or %NULL.
  * @error: a #GError for error reporting, or %NULL.
@@ -208,12 +209,13 @@ ggit_diff_new_tree_to_index (GgitRepository   *repository,
 	gint ret;
 
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
-	g_return_val_if_fail (GGIT_IS_TREE (old_tree), NULL);
+	g_return_val_if_fail (old_tree == NULL || GGIT_IS_TREE (old_tree), NULL);
+	g_return_val_if_fail (index == NULL || GGIT_IS_INDEX (index), NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	ret = git_diff_tree_to_index (&diff,
 	                              _ggit_native_get (repository),
-	                              _ggit_native_get (old_tree),
+	                              old_tree ? _ggit_native_get (old_tree) : NULL,
 	                              index ? _ggit_native_get (index) : NULL,
 	                              _ggit_diff_options_get_diff_options (diff_options));
 
@@ -251,6 +253,7 @@ ggit_diff_new_index_to_workdir (GgitRepository   *repository,
 	gint ret;
 
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+	g_return_val_if_fail (index == NULL || GGIT_IS_INDEX (index), NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	ret = git_diff_index_to_workdir (&diff,
@@ -270,7 +273,7 @@ ggit_diff_new_index_to_workdir (GgitRepository   *repository,
 /**
  * ggit_diff_new_tree_to_workdir:
  * @repository: a #GgitRepository.
- * @old_tree: a #GgitTree to diff from.
+ * @old_tree: (allow-none): a #GgitTree to diff from.
  * @diff_options: (allow-none): a #GgitDiffOptions, or %NULL.
  * @error: a #GError for error reporting, or %NULL.
  *
@@ -291,12 +294,12 @@ ggit_diff_new_tree_to_workdir (GgitRepository   *repository,
 	gint ret;
 
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
-	g_return_val_if_fail (GGIT_IS_TREE (old_tree), NULL);
+	g_return_val_if_fail (old_tree == NULL || GGIT_IS_TREE (old_tree), NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	ret = git_diff_tree_to_workdir (&diff,
 	                                _ggit_native_get (repository),
-	                                _ggit_native_get (old_tree),
+	                                old_tree ? _ggit_native_get (old_tree) : NULL,
 	                                _ggit_diff_options_get_diff_options (diff_options));
 
 	if (ret != GIT_OK)
@@ -470,9 +473,11 @@ ggit_diff_print_patch (GgitDiff              *diff,
 
 /**
  * ggit_diff_blobs:
- * @diff_options: (allow-none): a #GgitDiffOptions, or %NULL.
  * @old_blob: (allow-none): a #GgitBlob to diff from.
+ * @old_as_path: (allow-none): treat @old_blob as if it had this filename, or %NULL,
  * @new_blob: (allow-none): a #GgitBlob to diff to.
+ * @new_as_path: (allow-none): treat @new_blob as if it had this filename, or %NULL,
+ * @diff_options: (allow-none): a #GgitDiffOptions, or %NULL.
  * @file_cb: (allow-none) (scope call) (closure user_data):
  *  a #GgitDiffFileCallback.
  * @hunk_cb: (allow-none) (scope call) (closure user_data):
@@ -491,9 +496,11 @@ ggit_diff_print_patch (GgitDiff              *diff,
  * ggit_diff_options_new() are used.
  */
 void
-ggit_diff_blobs (GgitDiffOptions       *diff_options,
-                 GgitBlob              *old_blob,
+ggit_diff_blobs (GgitBlob              *old_blob,
+                 const gchar           *old_as_path,
                  GgitBlob              *new_blob,
+                 const gchar           *new_as_path,
+                 GgitDiffOptions       *diff_options,
                  GgitDiffFileCallback   file_cb,
                  GgitDiffHunkCallback   hunk_cb,
                  GgitDiffLineCallback   line_cb,
@@ -532,7 +539,9 @@ ggit_diff_blobs (GgitDiffOptions       *diff_options,
 	}
 
 	ret = git_diff_blobs (old_blob ? _ggit_native_get (old_blob) : NULL,
+	                      old_as_path,
 	                      new_blob ? _ggit_native_get (new_blob) : NULL,
+	                      new_as_path,
 	                      (git_diff_options *) gdiff_options,
 	                      real_file_cb, real_hunk_cb, real_line_cb,
 	                      &wrapper_data);
@@ -545,10 +554,12 @@ ggit_diff_blobs (GgitDiffOptions       *diff_options,
 
 /**
  * ggit_diff_blob_to_buffer:
- * @diff_options: (allow-none): a #GgitDiffOptions, or %NULL.
  * @old_blob: (allow-none): a #GgitBlob to diff from.
+ * @old_as_path: (allow-none): treat @old_blob as if it had this filename, or %NULL,
  * @buffer: (allow-none) (array length=buffer_len): a buffer to diff to.
  * @buffer_len: length of @buffer.
+ * @buffer_as_path: (allow-none): treat @buffer as if it had this filename, or %NULL,
+ * @diff_options: (allow-none): a #GgitDiffOptions, or %NULL.
  * @file_cb: (allow-none) (scope call) (closure user_data):
  *  a #GgitDiffFileCallback.
  * @hunk_cb: (allow-none) (scope call) (closure user_data):
@@ -561,10 +572,12 @@ ggit_diff_blobs (GgitDiffOptions       *diff_options,
  * Same as ggit_diff_blobs() but using a buffer.
  */
 void
-ggit_diff_blob_to_buffer (GgitDiffOptions       *diff_options,
-                          GgitBlob              *old_blob,
+ggit_diff_blob_to_buffer (GgitBlob              *old_blob,
+                          const gchar           *old_as_path,
                           const gchar           *buffer,
                           gsize                  buffer_len,
+                          const gchar           *buffer_as_path,
+                          GgitDiffOptions       *diff_options,
                           GgitDiffFileCallback   file_cb,
                           GgitDiffHunkCallback   hunk_cb,
                           GgitDiffLineCallback   line_cb,
@@ -603,8 +616,10 @@ ggit_diff_blob_to_buffer (GgitDiffOptions       *diff_options,
 	}
 
 	ret = git_diff_blob_to_buffer (old_blob ? _ggit_native_get (old_blob) : NULL,
+	                               old_as_path,
 	                               buffer,
 	                               buffer_len,
+	                               buffer_as_path,
 	                               (git_diff_options *) gdiff_options,
 	                               real_file_cb, real_hunk_cb, real_line_cb,
 	                               &wrapper_data);
