@@ -244,6 +244,9 @@ ggit_diff_line_type_get_type (void)
 			{ GGIT_DIFF_LINE_DELETION,
 			  "GGIT_DIFF_LINE_DELETION",
 			  "deletion" },
+			{ GGIT_DIFF_LINE_CONTEXT_EOFNL,
+			  "GGIT_DIFF_LINE_CONTEXT_EOFNL",
+			  "context-eofnl" },
 			{ GGIT_DIFF_LINE_ADD_EOFNL,
 			  "GGIT_DIFF_LINE_ADD_EOFNL",
 			  "add-eofnl" },
@@ -349,15 +352,12 @@ ggit_remote_download_tags_type_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ GGIT_REMOTE_DOWNLOAD_TAGS_UNSET,
-			  "GGIT_REMOTE_DOWNLOAD_TAGS_UNSET",
-			  "unset" },
-			{ GGIT_REMOTE_DOWNLOAD_TAGS_NONE,
-			  "GGIT_REMOTE_DOWNLOAD_TAGS_NONE",
-			  "none" },
 			{ GGIT_REMOTE_DOWNLOAD_TAGS_AUTO,
 			  "GGIT_REMOTE_DOWNLOAD_TAGS_AUTO",
 			  "auto" },
+			{ GGIT_REMOTE_DOWNLOAD_TAGS_NONE,
+			  "GGIT_REMOTE_DOWNLOAD_TAGS_NONE",
+			  "none" },
 			{ GGIT_REMOTE_DOWNLOAD_TAGS_ALL,
 			  "GGIT_REMOTE_DOWNLOAD_TAGS_ALL",
 			  "all" },
@@ -673,6 +673,85 @@ ggit_tree_walk_mode_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_status_option_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GFlagsValue values[] = {
+			{ GGIT_STATUS_OPTION_INCLUDE_UNTRACKED,
+			  "GGIT_STATUS_OPTION_INCLUDE_UNTRACKED",
+			  "include-untracked" },
+			{ GGIT_STATUS_OPTION_INCLUDE_IGNORED,
+			  "GGIT_STATUS_OPTION_INCLUDE_IGNORED",
+			  "include-ignored" },
+			{ GGIT_STATUS_OPTION_INCLUDE_UNMODIFIED,
+			  "GGIT_STATUS_OPTION_INCLUDE_UNMODIFIED",
+			  "include-unmodified" },
+			{ GGIT_STATUS_OPTION_EXCLUDE_SUBMODULES,
+			  "GGIT_STATUS_OPTION_EXCLUDE_SUBMODULES",
+			  "exclude-submodules" },
+			{ GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS,
+			  "GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS",
+			  "recurse-untracked-dirs" },
+			{ GGIT_STATUS_OPTION_DISABLE_PATHSPEC_MATCH,
+			  "GGIT_STATUS_OPTION_DISABLE_PATHSPEC_MATCH",
+			  "disable-pathspec-match" },
+			{ GGIT_STATUS_OPTION_RECURSE_IGNORED_DIRS,
+			  "GGIT_STATUS_OPTION_RECURSE_IGNORED_DIRS",
+			  "recurse-ignored-dirs" },
+			{ GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY,
+			  "GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY",
+			  "sort-case-sensitively" },
+			{ GGIT_STATUS_OPTION_SORT_CASE_INSENSITIVELY,
+			  "GGIT_STATUS_OPTION_SORT_CASE_INSENSITIVELY",
+			  "sort-case-insensitively" },
+			{ GGIT_STATUS_OPTION_DEFAULT,
+			  "GGIT_STATUS_OPTION_DEFAULT",
+			  "default" },
+			{ GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS,
+			  "GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS",
+			  "recurse-untracked-dirs" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_flags_register_static (
+				g_intern_static_string ("GgitStatusOption"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+ggit_status_show_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ GGIT_STATUS_SHOW_INDEX_AND_WORKDIR,
+			  "GGIT_STATUS_SHOW_INDEX_AND_WORKDIR",
+			  "index-and-workdir" },
+			{ GGIT_STATUS_SHOW_INDEX_ONLY,
+			  "GGIT_STATUS_SHOW_INDEX_ONLY",
+			  "index-only" },
+			{ GGIT_STATUS_SHOW_WORKDIR_ONLY,
+			  "GGIT_STATUS_SHOW_WORKDIR_ONLY",
+			  "workdir-only" },
+			{ GGIT_STATUS_SHOW_INDEX_THEN_WORKDIR,
+			  "GGIT_STATUS_SHOW_INDEX_THEN_WORKDIR",
+			  "index-then-workdir" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("GgitStatusShow"),
+				values);
+	}
+	return the_type;
+}
+
 
 /* Generated data ends here */
 
