@@ -22,6 +22,7 @@
 #include <git2/errors.h>
 #include <git2/repository.h>
 #include <git2/refs.h>
+#include <git2/diff.h>
 #include <git2/status.h>
 #include <git2/tag.h>
 #include <git2/branch.h>
@@ -31,6 +32,7 @@
 #include <git2/revparse.h>
 #include <git2/stash.h>
 #include <git2/graph.h>
+#include <git2/blob.h>
 
 #include "ggit-error.h"
 #include "ggit-oid.h"
@@ -41,6 +43,7 @@
 #include "ggit-submodule.h"
 #include "ggit-signature.h"
 #include "ggit-clone-options.h"
+#include "ggit-status-options.h"
 
 #define GGIT_REPOSITORY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GGIT_TYPE_REPOSITORY, GgitRepositoryPrivate))
 
@@ -1016,6 +1019,7 @@ ggit_repository_file_status (GgitRepository  *repository,
 /**
  * ggit_repository_file_status_foreach:
  * @repository: a #GgitRepository.
+ * @options: (allow-none): status options, or %NULL.
  * @callback: (scope call): a #GgitStatusCallback.
  * @user_data: callback user data.
  * @error: a #GError for error reporting, or %NULL.
@@ -1026,11 +1030,14 @@ ggit_repository_file_status (GgitRepository  *repository,
  * passed to this function. If the callback returns something other than
  * 0, the iteration will stop and @error will be set.
  *
+ * Set @options to %NULL to get the default status options.
+ *
  * Returns: %TRUE if there was no error, %FALSE otherwise
  *
  */
 gboolean
 ggit_repository_file_status_foreach (GgitRepository     *repository,
+                                     GgitStatusOptions  *options,
                                      GgitStatusCallback  callback,
                                      gpointer            user_data,
                                      GError            **error)
@@ -1041,9 +1048,10 @@ ggit_repository_file_status_foreach (GgitRepository     *repository,
 	g_return_val_if_fail (callback != NULL, FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	ret = git_status_foreach (_ggit_native_get (repository),
-	                          callback,
-	                          user_data);
+	ret = git_status_foreach_ext (_ggit_native_get (repository),
+	                              _ggit_status_options_get_status_options (options),
+	                              callback,
+	                              user_data);
 
 	if (ret != GIT_OK)
 	{
@@ -1055,10 +1063,9 @@ ggit_repository_file_status_foreach (GgitRepository     *repository,
 }
 
 /**
- * ggit_repository_references_foreach:
+ * ggit_repository_references_foreach_name:
  * @repository: a #GgitRepository.
- * @reftype: a #GgitRefType
- * @callback: (scope call): a #GgitReferencesCallback.
+ * @callback: (scope call): a #GgitReferencesNameCallback.
  * @user_data: callback user data.
  * @error: a #GError for error reporting, or %NULL.
  *
@@ -1066,18 +1073,16 @@ ggit_repository_file_status_foreach (GgitRepository     *repository,
  *
  * To the callback is passed the name of the reference and the data pointer
  * passed to this function. If the callback returns something other than
- * 0, the iteration will stop and @error will be set. The references are
- * filtered by @reftype.
+ * 0, the iteration will stop and @error will be set.
  *
  * Returns: %TRUE if there was no error, %FALSE otherwise
  *
  */
 gboolean
-ggit_repository_references_foreach (GgitRepository          *repository,
-                                    GgitRefType              reftype,
-                                    GgitReferencesCallback   callback,
-                                    gpointer                 user_data,
-                                    GError                 **error)
+ggit_repository_references_foreach_name (GgitRepository             *repository,
+                                         GgitReferencesNameCallback  callback,
+                                         gpointer                    user_data,
+                                         GError                    **error)
 {
 	gint ret;
 
@@ -1085,10 +1090,9 @@ ggit_repository_references_foreach (GgitRepository          *repository,
 	g_return_val_if_fail (callback != NULL, FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	ret = git_reference_foreach (_ggit_native_get (repository),
-	                             reftype,
-	                             callback,
-	                             user_data);
+	ret = git_reference_foreach_name (_ggit_native_get (repository),
+	                                  callback,
+	                                  user_data);
 
 	if (ret != GIT_OK)
 	{
@@ -1898,4 +1902,121 @@ ggit_repository_get_ahead_behind (GgitRepository  *repository,
 	}
 }
 
+/**
+ * ggit_repository_create_blob_from_buffer:
+ * @repository: a #GgitRepository.
+ * @buffer: (array length=size) (element-type guint8): the data.
+ * @size: the length (in bytes) of the data.
+ * @error: a #GError for error reporting, or %NULL.
+ *
+ * Write an in-memory buffer to the object database as a blob.
+ *
+ * @return the new #GgitOid of the written blob, or %NULL if writing the blob
+ * failed.
+ */
+GgitOId *
+ggit_repository_create_blob_from_buffer (GgitRepository  *repository,
+                                         gconstpointer    buffer,
+                                         gsize            size,
+                                         GError         **error)
+{
+	gint ret;
+	git_oid oid;
+
+	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+	g_return_val_if_fail (buffer != NULL, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	ret = git_blob_create_frombuffer (&oid,
+	                                  _ggit_native_get (repository),
+	                                  buffer,
+	                                  size);
+
+	if (ret != GIT_OK)
+	{
+		_ggit_error_set (error, ret);
+		return NULL;
+	}
+
+	return _ggit_oid_wrap (&oid);
+}
+
+/**
+ * ggit_repository_create_blob_from_file:
+ * @repository: a #GgitRepository.
+ * @file: a #GFile.
+ * @error: a #GError for error reporting, or %NULL.
+ *
+ * Write a file to the object database as a blob.
+ *
+ * @return the new #GgitOid of the written blob, or %NULL if writing the blob
+ * failed.
+ */
+GgitOId *
+ggit_repository_create_blob_from_file (GgitRepository  *repository,
+                                       GFile           *file,
+                                       GError         **error)
+{
+	gint ret;
+	git_oid oid;
+	gchar *path;
+
+	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+	g_return_val_if_fail (G_IS_FILE (file), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	path = g_file_get_path (file);
+
+	ret = git_blob_create_fromdisk (&oid,
+	                                _ggit_native_get (repository),
+	                                path);
+
+	g_free (path);
+
+	if (ret != GIT_OK)
+	{
+		_ggit_error_set (error, ret);
+		return NULL;
+	}
+
+	return _ggit_oid_wrap (&oid);
+}
+
+/**
+ * ggit_repository_create_blob_from_path:
+ * @repository: a #GgitRepository.
+ * @path: the file path.
+ * @error: a #GError for error reporting, or %NULL.
+ *
+ * Write a path relative to the repository working directory to the object
+ * database as a blob.
+ *
+ * @return the new #GgitOid of the written blob, or %NULL if writing the blob
+ * failed.
+ */
+GgitOId *
+ggit_repository_create_blob_from_path (GgitRepository  *repository,
+                                       const gchar     *path,
+                                       GError         **error)
+{
+	gint ret;
+	git_oid oid;
+
+	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+	g_return_val_if_fail (path != NULL, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	ret = git_blob_create_fromworkdir (&oid,
+	                                _ggit_native_get (repository),
+	                                path);
+
+	if (ret != GIT_OK)
+	{
+		_ggit_error_set (error, ret);
+		return NULL;
+	}
+
+	return _ggit_oid_wrap (&oid);
+}
+
 /* ex:set ts=8 noet: */
