@@ -257,6 +257,13 @@ typedef struct _GgitRevisionWalker GgitRevisionWalker;
  */
 typedef struct _GgitSignature GgitSignature;
 
+/**
+ * GgitStatusOptions:
+ *
+ * Represents the options used when creating getting file status.
+ */
+typedef struct _GgitStatusOptions GgitStatusOptions;
+
 /**
  * GgitSubmodule:
  *
@@ -292,6 +299,12 @@ typedef struct _GgitTree GgitTree;
  */
 typedef struct _GgitTreeEntry GgitTreeEntry;
 
+/**
+ * GgitTreeBuilder:
+ *
+ * Represents a tree object.
+ */
+typedef struct _GgitTreeBuilder GgitTreeBuilder;
 
 /**
  * GgitBranchType:
@@ -421,6 +434,7 @@ typedef enum {
  * @GGIT_DIFF_LINE_CONTEXT: line is part of the context.
  * @GGIT_DIFF_LINE_ADDITION: line that was added.
  * @GGIT_DIFF_LINE_DELETION: line that was removed.
+ * @GGIT_DIFF_LINE_CONTEXT_EOFNL: Both files have no LF at end.
  * @GGIT_DIFF_LINE_ADD_EOFNL: LF was added at end of file.
  * @GGIT_DIFF_LINE_DEL_EOFNL: LF was removed at end of file.
  * @GGIT_DIFF_LINE_FILE_HDR: the file header.
@@ -434,14 +448,15 @@ typedef enum {
  * #GGIT_DIFF_LINE_BINARY values are only sent when the diff is being printed.
  */
 typedef enum {
-	GGIT_DIFF_LINE_CONTEXT   = ' ',
-	GGIT_DIFF_LINE_ADDITION  = '+',
-	GGIT_DIFF_LINE_DELETION  = '-',
-	GGIT_DIFF_LINE_ADD_EOFNL = '\n',
-	GGIT_DIFF_LINE_DEL_EOFNL = '\0',
-	GGIT_DIFF_LINE_FILE_HDR  = 'F',
-	GGIT_DIFF_LINE_HUNK_HDR  = 'H',
-	GGIT_DIFF_LINE_BINARY    = 'B'
+	GGIT_DIFF_LINE_CONTEXT       = ' ',
+	GGIT_DIFF_LINE_ADDITION      = '+',
+	GGIT_DIFF_LINE_DELETION      = '-',
+	GGIT_DIFF_LINE_CONTEXT_EOFNL = '=',
+	GGIT_DIFF_LINE_ADD_EOFNL     = '>',
+	GGIT_DIFF_LINE_DEL_EOFNL     = '<',
+	GGIT_DIFF_LINE_FILE_HDR      = 'F',
+	GGIT_DIFF_LINE_HUNK_HDR      = 'H',
+	GGIT_DIFF_LINE_BINARY        = 'B'
 } GgitDiffLineType;
 
 /* NOTE: keep in sync with git2/errors.h */
@@ -480,16 +495,14 @@ typedef enum {
 /* NOTE: keep in sync with git2/refs.h */
 /**
  * GgitRemoteDownloadTagsType:
- * @GGIT_REMOTE_DOWNLOAD_TAGS_UNSET:
- * @GGIT_REMOTE_DOWNLOAD_TAGS_NONE:
  * @GGIT_REMOTE_DOWNLOAD_TAGS_AUTO:
+ * @GGIT_REMOTE_DOWNLOAD_TAGS_NONE:
  * @GGIT_REMOTE_DOWNLOAD_TAGS_ALL:
  */
 typedef enum {
-	GGIT_REMOTE_DOWNLOAD_TAGS_UNSET,
-	GGIT_REMOTE_DOWNLOAD_TAGS_NONE,
-	GGIT_REMOTE_DOWNLOAD_TAGS_AUTO,
-	GGIT_REMOTE_DOWNLOAD_TAGS_ALL
+	GGIT_REMOTE_DOWNLOAD_TAGS_AUTO = 0,
+	GGIT_REMOTE_DOWNLOAD_TAGS_NONE = 1,
+	GGIT_REMOTE_DOWNLOAD_TAGS_ALL  = 2
 } GgitRemoteDownloadTagsType;
 
 /* NOTE: keep in sync with git2/refs.h */
@@ -662,6 +675,57 @@ typedef enum {
 	GGIT_TREE_WALK_MODE_POST = 1,
 } GgitTreeWalkMode;
 
+/**
+ * GgitStatusOption:
+ * GGIT_STATUS_OPTION_INCLUDE_UNTRACKED: include untracked files (default).
+ * GGIT_STATUS_OPTION_INCLUDE_IGNORED: include ignored files (default).
+ * GGIT_STATUS_OPTION_INCLUDE_UNMODIFIED: include unmodified files.
+ * GGIT_STATUS_OPTION_EXCLUDE_SUBMODULES: exclude submodules.
+ * GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS: search untracked directories recursively (default).
+ * GGIT_STATUS_OPTION_DISABLE_PATHSPEC_MATCH: do not match path specifications.
+ * GGIT_STATUS_OPTION_RECURSE_IGNORED_DIRS: search ignored directories recursively.
+ * GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY: sort case sensitive.
+ * GGIT_STATUS_OPTION_SORT_CASE_INSENSITIVELY: sort case insensitive.
+ * GGIT_STATUS_OPTION_DEFAULT: default flags.
+ *
+ * Status options specified when using #ggit_repository_file_status_foreach.
+ *
+ */
+typedef enum {
+	GGIT_STATUS_OPTION_INCLUDE_UNTRACKED        = (1 << 0),
+	GGIT_STATUS_OPTION_INCLUDE_IGNORED          = (1 << 1),
+	GGIT_STATUS_OPTION_INCLUDE_UNMODIFIED       = (1 << 2),
+	GGIT_STATUS_OPTION_EXCLUDE_SUBMODULES       = (1 << 3),
+	GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS   = (1 << 4),
+	GGIT_STATUS_OPTION_DISABLE_PATHSPEC_MATCH   = (1 << 5),
+	GGIT_STATUS_OPTION_RECURSE_IGNORED_DIRS     = (1 << 6),
+	GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY    = (1 << 9),
+	GGIT_STATUS_OPTION_SORT_CASE_INSENSITIVELY  = (1 << 10),
+	GGIT_STATUS_OPTION_DEFAULT                  = GGIT_STATUS_OPTION_INCLUDE_IGNORED |
+	                                              GGIT_STATUS_OPTION_INCLUDE_UNTRACKED |
+	                                              GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS
+} GgitStatusOption;
+
+/**
+ * GgitStatusShow:
+ * @GGIT_STATUS_SHOW_INDEX_AND_WORKDIR: receive one callback for each file,
+ * even if the file is in both the index and the workdir (combining #GgitStatusFlags).
+ * @GGIT_STATUS_SHOW_INDEX_ONLY: only receive callbacks for files in the index.
+ * @GGIT_STATUS_SHOW_WORKDIR_ONLY: only receive callbacks for files in the workdir.
+ * @GGIT_STATUS_SHOW_INDEX_THEN_WORKDIR: receive callbacks first for files in
+ * the index, and then in the workdir. This is equivalent to first specifying
+ * #GGIT_STATUS_SHOW_INDEX_ONLY and then #GGIT_STATUS_SHOW_WORKDIR_ONLY.
+ *
+ * Show options for #ggit_repository_file_status_foreach. Determines which
+ * files are included in the status.
+ *
+ */
+typedef enum {
+	GGIT_STATUS_SHOW_INDEX_AND_WORKDIR = 0,
+	GGIT_STATUS_SHOW_INDEX_ONLY = 1,
+	GGIT_STATUS_SHOW_WORKDIR_ONLY = 2,
+	GGIT_STATUS_SHOW_INDEX_THEN_WORKDIR = 3,
+} GgitStatusShow;
 
 /**
  * GgitBranchesCallback:
@@ -779,17 +843,17 @@ typedef gint (* GgitDiffLineCallback) (GgitDiffDelta    *delta,
                                        gpointer          user_data);
 
 /**
- * GgitReferencesCallback:
+ * GgitReferencesNameCallback:
  * @name: the name of the reference
  * @user_data: (closure): user-supplied data.
  *
  * The type of the callback functions for retrieving the references
- * in a #GgitRepository. See ggit_repository_references_foreach().
+ * in a #GgitRepository. See ggit_repository_references_foreach_name().
  *
  * Returns: 0 to go for the next references or a #GgitError in case there was an error.
  */
-typedef gint (* GgitReferencesCallback) (const gchar *name,
-                                         gpointer     user_data);
+typedef gint (* GgitReferencesNameCallback) (const gchar *name,
+                                             gpointer     user_data);
 
 /**
  * GgitRemoteListCallback:
